##  Visualizing Future Changes of Transformations
To visualize the future changes that the transformations will bring to your IT landscape, do the following:
  1. Navigate to reports with a timeline.
  2. Click on Add an Initiative + button located on the left side of the timeline.
![Adding Initiative to the timeline](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2746de1d7a4410149a71c444c2d62dd6_LowRes.png)
Adding Initiative to the timeline
  3. From the selection window, select the Initiatives that include the Transformations whose impact you wish to visualize. Selecting the parent project is sufficient to view all the impacts; there's no need to choose every project in the hierarchy.
  4. Click Use Selected Fact Sheets.


With this, the impacts of the selected projects become visible in the report. Navigate to any point in time by clicking on the timeline. To compare the changes between two points in time, hold down the shift key and click on two points along the timeline.
If you want to view only the changes, go to the report settings and check the Show only changed Fact Sheets box.
![Report Setting to see only changed Fact Sheets](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749e7177a4410149ceddc497a2722fa_LowRes.png)
Report Setting to see only changed Fact Sheets
